==> libopenjpeg-devel-1.5.2-2.tar.xz: usr/lib/openjpeg-1.5/OpenJPEGTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "openjpeg" for configuration "RelWithDebInfo"
set_property(TARGET openjpeg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(openjpeg PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "/usr/lib/libopenjpeg.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELWITHDEBINFO "m"
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/cygopenjpeg-1.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS openjpeg )
list(APPEND _IMPORT_CHECK_FILES_FOR_openjpeg "/usr/lib/libopenjpeg.dll.a" "/usr/bin/cygopenjpeg-1.dll" )

# Import target "j2k_to_image" for configuration "RelWithDebInfo"
set_property(TARGET j2k_to_image APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(j2k_to_image PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/j2k_to_image.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS j2k_to_image )
list(APPEND _IMPORT_CHECK_FILES_FOR_j2k_to_image "/usr/bin/j2k_to_image.exe" )

# Import target "image_to_j2k" for configuration "RelWithDebInfo"
set_property(TARGET image_to_j2k APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(image_to_j2k PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/image_to_j2k.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS image_to_j2k )
list(APPEND _IMPORT_CHECK_FILES_FOR_image_to_j2k "/usr/bin/image_to_j2k.exe" )

# Import target "j2k_dump" for configuration "RelWithDebInfo"
set_property(TARGET j2k_dump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(j2k_dump PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "/usr/bin/j2k_dump.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS j2k_dump )
list(APPEND _IMPORT_CHECK_FILES_FOR_j2k_dump "/usr/bin/j2k_dump.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libopenjpeg-devel-1.5.2-3.tar.xz: usr/lib/openjpeg-1.5/OpenJPEGTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "openjpeg" for configuration "RelWithDebInfo"
set_property(TARGET openjpeg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(openjpeg PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libopenjpeg.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELWITHDEBINFO "m"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygopenjpeg-1.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS openjpeg )
list(APPEND _IMPORT_CHECK_FILES_FOR_openjpeg "${_IMPORT_PREFIX}/lib/libopenjpeg.dll.a" "${_IMPORT_PREFIX}/bin/cygopenjpeg-1.dll" )

# Import target "j2k_to_image" for configuration "RelWithDebInfo"
set_property(TARGET j2k_to_image APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(j2k_to_image PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/j2k_to_image.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS j2k_to_image )
list(APPEND _IMPORT_CHECK_FILES_FOR_j2k_to_image "${_IMPORT_PREFIX}/bin/j2k_to_image.exe" )

# Import target "image_to_j2k" for configuration "RelWithDebInfo"
set_property(TARGET image_to_j2k APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(image_to_j2k PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/image_to_j2k.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS image_to_j2k )
list(APPEND _IMPORT_CHECK_FILES_FOR_image_to_j2k "${_IMPORT_PREFIX}/bin/image_to_j2k.exe" )

# Import target "j2k_dump" for configuration "RelWithDebInfo"
set_property(TARGET j2k_dump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(j2k_dump PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/j2k_dump.exe"
  )

list(APPEND _IMPORT_CHECK_TARGETS j2k_dump )
list(APPEND _IMPORT_CHECK_FILES_FOR_j2k_dump "${_IMPORT_PREFIX}/bin/j2k_dump.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
